==========
Djangondor
==========

Djangondor is a collection Django utilities.

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "djangondor" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...,
        "djangondor",
    ]

2. See the documentation at <https://github.com/DalitsoSakala/djangondor/blob/main/djangondor/docs/INDEX.md>